# Changelog

<!-- towncrier release notes start -->

## [1.0.1](https://github.com/Nagidal/hatch-semver/tree/1.0.1) - 2022-11-17


### Documentation

- Fixed typos and errors in the documentation [#59](https://github.com/Nagidal/hatch-semver/issues/59)
- Set correct project homepage in `pyproject.toml`. It should be now linked from [PyPI](https://pypi.org/project/hatch-semver/). [#64](https://github.com/Nagidal/hatch-semver/issues/64)


### Development Details

- Set current date in `__about__.py` [#61](https://github.com/Nagidal/hatch-semver/issues/61)
- Wrote a test for current date in `__about__.py` [#62](https://github.com/Nagidal/hatch-semver/issues/62)
- Wrote a test for current version in the changelog [#63](https://github.com/Nagidal/hatch-semver/issues/63)


## [1.0.0](https://github.com/Nagidal/hatch-semver/tree/1.0.0) - 2022-11-17


### New Features

- Released v1.0.0 [#57](https://github.com/Nagidal/hatch-semver/issues/57)


## [1.0.0-rc.4](https://github.com/Nagidal/hatch-semver/tree/1.0.0-rc.4) - 2022-11-16


### Documentation

- Renamed User Documentation Workflow to Master PR Closed [#53](https://github.com/Nagidal/hatch-semver/issues/53)


### Development Details

- Test stage is set up [#51](https://github.com/Nagidal/hatch-semver/issues/51)


## [1.0.0-rc.3](https://github.com/Nagidal/hatch-semver/tree/1.0.0-rc.3) - 2022-11-16


### Documentation

- Using admonitions [#44](https://github.com/Nagidal/hatch-semver/issues/44)
- Using a note admonition in `index.md` [#49](https://github.com/Nagidal/hatch-semver/issues/49)


### Development Details

- Using actions/checkout@v3 in the CI [#46](https://github.com/Nagidal/hatch-semver/issues/46)
- Using setup-python@v4 in the CI [#47](https://github.com/Nagidal/hatch-semver/issues/47)


## [1.0.0-rc.2](https://github.com/Nagidal/hatch-semver/tree/1.0.0-rc.2) - 2022-11-16


### Documentation

- Using admonitions [#44](https://github.com/Nagidal/hatch-semver/issues/44)


### Development Details

- Using actions/checkout@v3 in the CI [#46](https://github.com/Nagidal/hatch-semver/issues/46)
- Using setup-python@v4 in the CI [#47](https://github.com/Nagidal/hatch-semver/issues/47)


## [1.0.0-rc.1](https://github.com/Nagidal/hatch-semver/tree/1.0.0-rc.1) - 2022-11-16


### Documentation

- Using PowerShell instead of cmd commands in pyproject [#35](https://github.com/Nagidal/hatch-semver/issues/35)
- Added githooks to the repo. Set your core.hookspath to `.githooks` [#36](https://github.com/Nagidal/hatch-semver/issues/36)
- Updated links to published documentation in `README.md` [#43](https://github.com/Nagidal/hatch-semver/issues/43)


### Development Details

- Deleted unnecessary copy of the documentation [#41](https://github.com/Nagidal/hatch-semver/issues/41)
- Better documentation pipeline [#42](https://github.com/Nagidal/hatch-semver/issues/42)


## [0.2.4](https://github.com/Nagidal/hatch-semver/tree/0.2.4) - 2022-11-15


### Development Details

- Using PowerShell instead of cmd commands in pyproject [#35](https://github.com/Nagidal/hatch-semver/issues/35)
- Added githooks to the repo. Set your core.hookspath to `.githooks` [#36](https://github.com/Nagidal/hatch-semver/issues/36)


## [0.2.4-rc.1](https://github.com/Nagidal/hatch-semver/tree/0.2.4-rc.1) - 2022-11-15


### Development Details

- Use hatch-semver for versioning [#33](https://github.com/Nagidal/hatch-semver/issues/33)


## [0.2.3](https://github.com/Nagidal/hatch-semver/tree/0.2.3) - 2022-11-15


### Documentation

- Separated home.md from README.md [#31](https://github.com/Nagidal/hatch-semver/issues/31)


## [0.2.2](https://github.com/Nagidal/hatch-semver/tree/0.2.2) - 2022-11-15


### Documentation

- Removed api-docs [#29](https://github.com/Nagidal/hatch-semver/issues/29)


## [0.2.1](https://github.com/Nagidal/hatch-semver/tree/0.2.1) - 2022-11-15


### Documentation

- Moved user-docs to docs [#27](https://github.com/Nagidal/hatch-semver/issues/27)


## [0.2.0](https://github.com/Nagidal/hatch-semver/tree/0.2.0) - 2022-11-15


### Documentation

- Wrote user and api documentation [#25](https://github.com/Nagidal/hatch-semver/issues/25)


## [0.1.0](https://github.com/Nagidal/hatch-semver/tree/0.1.0) - 2022-11-13


### New Features

- Added inline options for prerelease and build tokens [#23](https://github.com/Nagidal/hatch-semver/issues/23)


### Bugfixes

- Fixed undefined ValeError [#16](https://github.com/Nagidal/hatch-semver/issues/16)
- Can bump prereleases now [#17](https://github.com/Nagidal/hatch-semver/issues/17)
- Can bump builds now [#18](https://github.com/Nagidal/hatch-semver/issues/18)
- Can update version to release [#22](https://github.com/Nagidal/hatch-semver/issues/22)


### Development Details

- Created tests [#19](https://github.com/Nagidal/hatch-semver/issues/19)


## [0.0.8](https://github.com/Nagidal/hatch-semver/tree/0.0.8) - 2022-11-10


### Bugfixes

- Fixed another ValueError when bumping major version [#14](https://github.com/Nagidal/hatch-semver/issues/14)


## [0.0.7](https://github.com/Nagidal/hatch-semver/tree/0.0.7) - 2022-11-10


### Bugfixes

- Fixed NameError when bumping version [#12](https://github.com/Nagidal/hatch-semver/issues/12)


## [0.0.6](https://github.com/Nagidal/hatch-semver/tree/0.0.6) - 2022-11-10


### Bugfixes

- Major version should be bumpable now [#10](https://github.com/Nagidal/hatch-semver/issues/10)


## [0.0.5](https://github.com/Nagidal/hatch-semver/tree/0.0.5) - 2022-11-10

No significant changes.


## [0.0.4](https://github.com/Nagidal/hatch-semver/tree/0.0.4) - 2022-11-10


### Development Details

- Plugin structure is ready, should know how to bump major, minor, patch [#2](https://github.com/Nagidal/hatch-semver/issues/2)


### Documentation

- Better readme, but not final [#8](https://github.com/Nagidal/hatch-semver/issues/8)


## [0.0.3](https://github.com/Nagidal/hatch-semver/tree/0.0.3) - 2022-11-10


### Bugfixes

- Renamed module to hatch_semver [#6](https://github.com/Nagidal/hatch-semver/issues/6)


## [0.0.2](https://github.com/Nagidal/hatch-semver/tree/0.0.2) - 2022-11-10


### Development Details

- Prepared project [#1](https://github.com/Nagidal/hatch-semver/issues/1)


### Bugfixes

- Fixed plugin hook path [#4](https://github.com/Nagidal/hatch-semver/issues/4)


